@@ -121,15 +121,16 @@ hetglm.control <- function(method = "nlminb", maxit = 1000, hessian = FALSE, tra
 hetglm.fit <- function(x, y, z = NULL, weights = NULL, offset = NULL,
   family = binomial(), link.scale = "log", control = hetglm.control())
 {
-  ## response
+  ## number of observations
   nobs <- n <- NROW(x)
-  if(is.null(weights)) weights <- rep.int(1L, n)
-  if(is.null(offset)) offset <- list(mean = rep.int(0, n), scale = rep.int(0, n))
+
+  ## response
+  if(is.null(weights)) weights <- rep.int(1L, nobs)
+  if(is.null(offset)) offset <- list(mean = rep.int(0, nobs), scale = rep.int(0, nobs))
   start <- etastart <- mustart <- NULL
   eval(family$initialize)
 
   ## regressors
-  n <- NROW(x)
   k <- NCOL(x)
   if(is.null(z)) z <- x[, -1L, drop = FALSE]
   m <- NCOL(z)
@@ -242,7 +243,6 @@ hetglm.fit <- function(x, y, z = NULL, weights = NULL, offset = NULL,
     opt <- optim(par = start, fn = loglikfun, gr = gradfun,
       method = method, hessian = hessian, control = control)
     if(opt$convergence > 0) warning("optimization failed to converge")
-  
   }
 
 
@@ -255,7 +255,8 @@ hetglm.fit <- function(x, y, z = NULL, weights = NULL, offset = NULL,
   scale <- scale_linkinv(scale_eta)
   mu <- linkinv(eta / scale)
   phi <- dispersion((y - mu) / variance(mu), mu.eta(eta) / scale)
-  nobs <- sum(weights > 0L)  
+  nobs <- sum(weights > 0L)
+  n0 <- length(mu)
 
 
   ## names
@@ -275,9 +276,9 @@ hetglm.fit <- function(x, y, z = NULL, weights = NULL, offset = NULL,
     method = method,
     control = control,
     start = start,
-    weights = if(identical(as.vector(weights), rep(1, n))) NULL else weights,
-    offset = if(identical(offset, list(mean = rep(0, n), scale = rep(0, n)))) NULL else offset,
-    n = n,
+    weights = if(identical(as.vector(weights), rep(1, n0))) NULL else weights,
+    offset = if(identical(offset, list(mean = rep(0, n0), scale = rep(0, n0)))) NULL else offset,
+    n = n0,
     nobs = nobs,
     df.null = nobs - k,
     df.residual = nobs - k - m,
@@ -387,7 +388,7 @@ print.summary.hetglm <- function(x, digits = max(3, getOption("digits") - 3), ..
   
     cat("\nLog-likelihood:", formatC(x$loglik, digits = digits),
       "on", sum(sapply(x$coefficients, NROW)), "Df")
-    if(!is.na(x$lrtest[1])) cat("\nLR test for homoskedasticity:",
+    if(!is.na(x$lrtest[1])) cat("\nLR test for homoscedasticity:",
       formatC(x$lrtest[1], digits = digits), "on", x$lrtest[2], "Df, p-value:", format.pval(x$lrtest[3], digits = digits))
     cat("\nDispersion:", if(x$dispersion == 1L) "1" else formatC(x$dispersion, digits = digits))
     cat(paste("\nNumber of iterations in", x$method, "optimization:", x$iterations, "\n"))
